==> ogre-14.3.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_ogre_gpu_program_params_8h.js <==
var _ogre_gpu_program_params_8h =
[
    [ "Ogre::GpuProgramParameters::AutoConstantDefinition", "struct_ogre_1_1_gpu_program_parameters_1_1_auto_constant_definition.html", "struct_ogre_1_1_gpu_program_parameters_1_1_auto_constant_definition" ],
    [ "Ogre::GpuProgramParameters::AutoConstantEntry", "class_ogre_1_1_gpu_program_parameters_1_1_auto_constant_entry.html", "class_ogre_1_1_gpu_program_parameters_1_1_auto_constant_entry" ],
    [ "Ogre::GpuConstantDefinitionMap", "group___materials.html#gae4823c1377e5d4c312a3da9d1cb8534a", null ],
    [ "Ogre::GpuConstantDefinitionIterator", "group___materials.html#gaff7bf5891ea6cfed80f4e50edc5d3695", null ],
    [ "Ogre::GpuLogicalIndexUseMap", "group___materials.html#gaa51ba56cbce3f845ffd4be59ec30fd83", null ],
    [ "Ogre::ConstantList", "group___materials.html#ga01f98a5173473f9dd272d1e4f3ce9023", null ],
    [ "Ogre::BaseConstantType", "group___materials.html#ga31815ee0cc489402a8be91f2c87a84c6", [
      [ "Ogre::BCT_FLOAT", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6aa6bd4b93f8b01aa9ff63a94f9d59ed4b", null ],
      [ "Ogre::BCT_INT", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6af0903ec1ab5856e099a8bdb0a318b80f", null ],
      [ "Ogre::BCT_DOUBLE", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6a00de0bee5011412b3aee8c63fc32b979", null ],
      [ "Ogre::BCT_UINT", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6abe264bffc1f4cb447adcbfc7b79d3ec6", null ],
      [ "Ogre::BCT_BOOL", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6ad5369a580682614e352f3488844835d6", null ],
      [ "Ogre::BCT_SAMPLER", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6a0bcc8e6b3490ee8f9d705a10643bf239", null ],
      [ "Ogre::BCT_SPECIALIZATION", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6a7b822570bb4b807cbea56c9a4f31bf4a", null ],
      [ "Ogre::BCT_UNKNOWN", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6a3cd1fb77f4d729dd407cece2fdaaff9b", null ]
    ] ],
    [ "Ogre::GpuConstantType", "group___materials.html#ga9c5b2950be06ff56a6ee0bace240d447", [
      [ "Ogre::GCT_FLOAT1", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a2e6d0cad211d29d14774e0ca147dcd30", null ],
      [ "Ogre::GCT_FLOAT2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a979f39c4955889813f82374df96f6181", null ],
      [ "Ogre::GCT_FLOAT3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447abf2aed5efd251c030794ec27a7174fc8", null ],
      [ "Ogre::GCT_FLOAT4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a466febc90367dab6c895c98edfff7681", null ],
      [ "Ogre::GCT_SAMPLER1D", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a99d7d2b7976d0ef3b940f01e017b54ed", null ],
      [ "Ogre::GCT_SAMPLER2D", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a4f4eec3ce315c9a1ed97f47689241b64", null ],
      [ "Ogre::GCT_SAMPLER3D", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a18d1b343f2ec603945d3d7875622637a", null ],
      [ "Ogre::GCT_SAMPLERCUBE", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a13e953e084eb700f0bf55a42f6cae138", null ],
      [ "Ogre::GCT_SAMPLER1DSHADOW", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a37ce33389359aac73400ae427d9920fa", null ],
      [ "Ogre::GCT_SAMPLER2DSHADOW", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447acea2c4e9feb93413f97ce9c045269a50", null ],
      [ "Ogre::GCT_SAMPLER2DARRAY", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447adcacdabe1213322ebee0bc64ac4db387", null ],
      [ "Ogre::GCT_SAMPLER_EXTERNAL_OES", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447af416d0d2d80c90b17edeabac2e1a764d", null ],
      [ "Ogre::GCT_MATRIX_2X2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a0b2767a1b36c8e7821979adb15615c7a", null ],
      [ "Ogre::GCT_MATRIX_2X3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447abd03cb2cf3acde19f3a348e6146dd3e9", null ],
      [ "Ogre::GCT_MATRIX_2X4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a964c921cd7327eb271da6eb78742a850", null ],
      [ "Ogre::GCT_MATRIX_3X2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a80cbab72631a6efe3feaed44bf01e97e", null ],
      [ "Ogre::GCT_MATRIX_3X3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a0128d0683a17c232bb249a068c65cbd7", null ],
      [ "Ogre::GCT_MATRIX_3X4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a87a7bc0df0623b02534894a90d634f6d", null ],
      [ "Ogre::GCT_MATRIX_4X2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a33f4e8ee7271ce5353aa53c04c18447d", null ],
      [ "Ogre::GCT_MATRIX_4X3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a5b26aaa1925eaa7bb83dd4a9e25b28d5", null ],
      [ "Ogre::GCT_MATRIX_4X4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a01541907f48e2d56b7198a4076996a43", null ],
      [ "Ogre::GCT_INT1", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447ad023a5c54e29999cee04d54971cc5691", null ],
      [ "Ogre::GCT_INT2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447afce84063333829487cd0401fca732092", null ],
      [ "Ogre::GCT_INT3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a18edb505f8205cfed6bb28da3abefd53", null ],
      [ "Ogre::GCT_INT4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a278c0c55560cb39e67ce17239dc8184e", null ],
      [ "Ogre::GCT_SPECIALIZATION", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447ad96ce00c95c679a24e61608f5e8af027", null ],
      [ "Ogre::GCT_DOUBLE1", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a8b3dbac5bcc76ed764156f15e80a05a4", null ],
      [ "Ogre::GCT_DOUBLE2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a93e2780756cb91ab3c76762cc5eda3f2", null ],
      [ "Ogre::GCT_DOUBLE3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a0ed3c2a32cb8a267f0b1331bff4926b3", null ],
      [ "Ogre::GCT_DOUBLE4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447adca8e51d405a2b7a796e761453225cb6", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_2X2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447aab2f63a7282993278af3052e766112b2", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_2X3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a95ab6bf3295a610ee401aa62f479066f", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_2X4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a7859cf4200f613f49e1b5aaf592a8000", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_3X2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a968a42bab0cb6816755b5d43025354bf", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_3X3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a095e597780484dd735988a215be296c3", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_3X4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a817bd1af1704a732eff1646c904b3fd0", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_4X2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447ad9fae90ecc4c94651144f418f02a7238", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_4X3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447ab63321e0eda6f9cae96c7b44ea6b5c38", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_4X4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a861649f967aa3315ed74cfc9569c91a7", null ],
      [ "Ogre::GCT_UINT1", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a2004f6b55f308bb76f4aa2c8281945b4", null ],
      [ "Ogre::GCT_UINT2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447ad6544d6a653aceace5f368085563fd44", null ],
      [ "Ogre::GCT_UINT3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447acebec340cc9335f4f88fc71146257afe", null ],
      [ "Ogre::GCT_UINT4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a0ab3f9963906da1c191ab5b9133be5e2", null ],
      [ "Ogre::GCT_BOOL1", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a93253e1bc915a9f0af08c6bb95bfb9b9", null ],
      [ "Ogre::GCT_BOOL2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a3ef4a1bd9c9a80556f3865b4ede894f4", null ],
      [ "Ogre::GCT_BOOL3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a245d1d3186becdb492bed56badab0736", null ],
      [ "Ogre::GCT_BOOL4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a1365ccb2f8a08da774a25205c8535cb6", null ],
      [ "Ogre::GCT_UNKNOWN", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a3b3c9d05e75e6c20fd106d0f0080ad7e", null ]
    ] ],
    [ "Ogre::GpuParamVariability", "group___materials.html#ga70ed56150c1d09e77965d8bf52531e54", [
      [ "Ogre::GPV_GLOBAL", "group___materials.html#gga70ed56150c1d09e77965d8bf52531e54a756d7f053db5b3bc0d38c15d98cda93f", null ],
      [ "Ogre::GPV_PER_OBJECT", "group___materials.html#gga70ed56150c1d09e77965d8bf52531e54a39d4c360141a21c7dd916c7837b357af", null ],
      [ "Ogre::GPV_LIGHTS", "group___materials.html#gga70ed56150c1d09e77965d8bf52531e54ad782ae3173a29e4a2e28215489c5147b", null ],
      [ "Ogre::GPV_PASS_ITERATION_NUMBER", "group___materials.html#gga70ed56150c1d09e77965d8bf52531e54a30bc7bdcc3f0930c8dfb66c70eaecf4d", null ],
      [ "Ogre::GPV_ALL", "group___materials.html#gga70ed56150c1d09e77965d8bf52531e54a76c85c18f88b57983f861ee83fccde4a", null ]
    ] ]
];

==> ogre-14.4.1-2-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_ogre_gpu_program_params_8h.js <==
var _ogre_gpu_program_params_8h =
[
    [ "Ogre::GpuProgramParameters::AutoConstantDefinition", "struct_ogre_1_1_gpu_program_parameters_1_1_auto_constant_definition.html", "struct_ogre_1_1_gpu_program_parameters_1_1_auto_constant_definition" ],
    [ "Ogre::GpuProgramParameters::AutoConstantEntry", "class_ogre_1_1_gpu_program_parameters_1_1_auto_constant_entry.html", "class_ogre_1_1_gpu_program_parameters_1_1_auto_constant_entry" ],
    [ "Ogre::GpuConstantDefinitionMap", "group___materials.html#gae4823c1377e5d4c312a3da9d1cb8534a", null ],
    [ "Ogre::GpuConstantDefinitionIterator", "group___materials.html#gaff7bf5891ea6cfed80f4e50edc5d3695", null ],
    [ "Ogre::GpuLogicalIndexUseMap", "group___materials.html#gaa51ba56cbce3f845ffd4be59ec30fd83", null ],
    [ "Ogre::ConstantList", "group___materials.html#ga01f98a5173473f9dd272d1e4f3ce9023", null ],
    [ "Ogre::BaseConstantType", "group___materials.html#ga31815ee0cc489402a8be91f2c87a84c6", [
      [ "Ogre::BCT_FLOAT", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6aa6bd4b93f8b01aa9ff63a94f9d59ed4b", null ],
      [ "Ogre::BCT_INT", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6af0903ec1ab5856e099a8bdb0a318b80f", null ],
      [ "Ogre::BCT_DOUBLE", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6a00de0bee5011412b3aee8c63fc32b979", null ],
      [ "Ogre::BCT_UINT", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6abe264bffc1f4cb447adcbfc7b79d3ec6", null ],
      [ "Ogre::BCT_BOOL", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6ad5369a580682614e352f3488844835d6", null ],
      [ "Ogre::BCT_SAMPLER", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6a0bcc8e6b3490ee8f9d705a10643bf239", null ],
      [ "Ogre::BCT_SPECIALIZATION", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6a7b822570bb4b807cbea56c9a4f31bf4a", null ],
      [ "Ogre::BCT_UNKNOWN", "group___materials.html#gga31815ee0cc489402a8be91f2c87a84c6a3cd1fb77f4d729dd407cece2fdaaff9b", null ]
    ] ],
    [ "Ogre::GpuConstantType", "group___materials.html#ga9c5b2950be06ff56a6ee0bace240d447", [
      [ "Ogre::GCT_FLOAT1", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a2e6d0cad211d29d14774e0ca147dcd30", null ],
      [ "Ogre::GCT_FLOAT2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a979f39c4955889813f82374df96f6181", null ],
      [ "Ogre::GCT_FLOAT3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447abf2aed5efd251c030794ec27a7174fc8", null ],
      [ "Ogre::GCT_FLOAT4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a466febc90367dab6c895c98edfff7681", null ],
      [ "Ogre::GCT_SAMPLER1D", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a99d7d2b7976d0ef3b940f01e017b54ed", null ],
      [ "Ogre::GCT_SAMPLER2D", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a4f4eec3ce315c9a1ed97f47689241b64", null ],
      [ "Ogre::GCT_SAMPLER3D", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a18d1b343f2ec603945d3d7875622637a", null ],
      [ "Ogre::GCT_SAMPLERCUBE", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a13e953e084eb700f0bf55a42f6cae138", null ],
      [ "Ogre::GCT_SAMPLER1DSHADOW", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a37ce33389359aac73400ae427d9920fa", null ],
      [ "Ogre::GCT_SAMPLER2DSHADOW", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447acea2c4e9feb93413f97ce9c045269a50", null ],
      [ "Ogre::GCT_SAMPLER2DARRAY", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447adcacdabe1213322ebee0bc64ac4db387", null ],
      [ "Ogre::GCT_SAMPLER_EXTERNAL_OES", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447af416d0d2d80c90b17edeabac2e1a764d", null ],
      [ "Ogre::GCT_SAMPLER2DARRAYSHADOW", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a783288da9e3419974ace83d800f46e79", null ],
      [ "Ogre::GCT_SAMPLERCUBESHADOW", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a6846cd488fdb6671e126f32b07f1ee98", null ],
      [ "Ogre::GCT_MATRIX_2X2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a0b2767a1b36c8e7821979adb15615c7a", null ],
      [ "Ogre::GCT_MATRIX_2X3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447abd03cb2cf3acde19f3a348e6146dd3e9", null ],
      [ "Ogre::GCT_MATRIX_2X4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a964c921cd7327eb271da6eb78742a850", null ],
      [ "Ogre::GCT_MATRIX_3X2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a80cbab72631a6efe3feaed44bf01e97e", null ],
      [ "Ogre::GCT_MATRIX_3X3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a0128d0683a17c232bb249a068c65cbd7", null ],
      [ "Ogre::GCT_MATRIX_3X4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a87a7bc0df0623b02534894a90d634f6d", null ],
      [ "Ogre::GCT_MATRIX_4X2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a33f4e8ee7271ce5353aa53c04c18447d", null ],
      [ "Ogre::GCT_MATRIX_4X3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a5b26aaa1925eaa7bb83dd4a9e25b28d5", null ],
      [ "Ogre::GCT_MATRIX_4X4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a01541907f48e2d56b7198a4076996a43", null ],
      [ "Ogre::GCT_INT1", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447ad023a5c54e29999cee04d54971cc5691", null ],
      [ "Ogre::GCT_INT2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447afce84063333829487cd0401fca732092", null ],
      [ "Ogre::GCT_INT3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a18edb505f8205cfed6bb28da3abefd53", null ],
      [ "Ogre::GCT_INT4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a278c0c55560cb39e67ce17239dc8184e", null ],
      [ "Ogre::GCT_SPECIALIZATION", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447ad96ce00c95c679a24e61608f5e8af027", null ],
      [ "Ogre::GCT_DOUBLE1", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a8b3dbac5bcc76ed764156f15e80a05a4", null ],
      [ "Ogre::GCT_DOUBLE2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a93e2780756cb91ab3c76762cc5eda3f2", null ],
      [ "Ogre::GCT_DOUBLE3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a0ed3c2a32cb8a267f0b1331bff4926b3", null ],
      [ "Ogre::GCT_DOUBLE4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447adca8e51d405a2b7a796e761453225cb6", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_2X2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447aab2f63a7282993278af3052e766112b2", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_2X3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a95ab6bf3295a610ee401aa62f479066f", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_2X4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a7859cf4200f613f49e1b5aaf592a8000", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_3X2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a968a42bab0cb6816755b5d43025354bf", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_3X3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a095e597780484dd735988a215be296c3", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_3X4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a817bd1af1704a732eff1646c904b3fd0", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_4X2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447ad9fae90ecc4c94651144f418f02a7238", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_4X3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447ab63321e0eda6f9cae96c7b44ea6b5c38", null ],
      [ "Ogre::GCT_MATRIX_DOUBLE_4X4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a861649f967aa3315ed74cfc9569c91a7", null ],
      [ "Ogre::GCT_UINT1", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a2004f6b55f308bb76f4aa2c8281945b4", null ],
      [ "Ogre::GCT_UINT2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447ad6544d6a653aceace5f368085563fd44", null ],
      [ "Ogre::GCT_UINT3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447acebec340cc9335f4f88fc71146257afe", null ],
      [ "Ogre::GCT_UINT4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a0ab3f9963906da1c191ab5b9133be5e2", null ],
      [ "Ogre::GCT_BOOL1", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a93253e1bc915a9f0af08c6bb95bfb9b9", null ],
      [ "Ogre::GCT_BOOL2", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a3ef4a1bd9c9a80556f3865b4ede894f4", null ],
      [ "Ogre::GCT_BOOL3", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a245d1d3186becdb492bed56badab0736", null ],
      [ "Ogre::GCT_BOOL4", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a1365ccb2f8a08da774a25205c8535cb6", null ],
      [ "Ogre::GCT_UNKNOWN", "group___materials.html#gga9c5b2950be06ff56a6ee0bace240d447a3b3c9d05e75e6c20fd106d0f0080ad7e", null ]
    ] ],
    [ "Ogre::GpuParamVariability", "group___materials.html#ga70ed56150c1d09e77965d8bf52531e54", [
      [ "Ogre::GPV_GLOBAL", "group___materials.html#gga70ed56150c1d09e77965d8bf52531e54a756d7f053db5b3bc0d38c15d98cda93f", null ],
      [ "Ogre::GPV_PER_OBJECT", "group___materials.html#gga70ed56150c1d09e77965d8bf52531e54a39d4c360141a21c7dd916c7837b357af", null ],
      [ "Ogre::GPV_LIGHTS", "group___materials.html#gga70ed56150c1d09e77965d8bf52531e54ad782ae3173a29e4a2e28215489c5147b", null ],
      [ "Ogre::GPV_PASS_ITERATION_NUMBER", "group___materials.html#gga70ed56150c1d09e77965d8bf52531e54a30bc7bdcc3f0930c8dfb66c70eaecf4d", null ],
      [ "Ogre::GPV_ALL", "group___materials.html#gga70ed56150c1d09e77965d8bf52531e54a76c85c18f88b57983f861ee83fccde4a", null ]
    ] ]
];
